Endpoints class

An object containing epic endpoints used by the library

Constructors

Endpoints()

Properties

accountAvatars → String
no setter
accountDisplayName → String
no setter
accountEmail → String
no setter
accountId → String
no setter
accountMultiple → String
no setter
addFriend → String
no setter
blockFriend → String
no setter
brInventory → String
no setter
brStats → String
no setter
calderaToken → String
no setter
eventFlags → String
no setter
fortniteCatalog → String
no setter
fortniteParty → String
no setter
fortniteStatus → String
no setter
friends → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
mcp → String
no setter
oauthDeviceAuth → String
no setter
oauthDeviceCode → String
no setter
oauthExchange → String
no setter
oauthTokenCreate → String
no setter
oauthTokenDelete → String
no setter
oauthTokenDeleteMultiple → String
no setter
oauthTokenVerify → String
no setter
removeFriend → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userSearch → String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited